@@ -5,7 +5,6 @@ import dash
 import flask
 import plotly
 import pkgutil
-import requests
 import mimetypes
 import dash_renderer
 import dash_core_components as dcc
@@ -188,6 +187,7 @@ class OAPDash(dash.Dash):
         body = pkgutil.get_data('analytics_sdk', 'analysis-wrapper/main.js').decode("utf-8")
         response = flask.Response(body, mimetype='application/javascript')
         return response
+
     def _serve_report_main_js(self):
         dev = self._dev_tools.serve_dev_bundles
         body = f"var oap_config = {json.dumps(self._config(), cls=plotly.utils.PlotlyJSONEncoder)};\n"
@@ -222,7 +222,6 @@ class OAPDash(dash.Dash):
           + self.scripts._resources._filter_resources(dash_renderer._js_dist, dev_bundles=dev)
         )
 
-        srcs = []
         for resource in resources:
             is_dynamic_resource = resource.get("dynamic", False)
 
@@ -254,12 +253,14 @@ class OAPDash(dash.Dash):
 
     def pre_process(self, txt_body, file_name, dev):
         if file_name.startswith('dash_renderer.'):
-            txt_body = txt_body.replace("JSON.parse(document.getElementById('_dash-config').textContent);", "oap_config;")
+            txt_body = txt_body.replace("JSON.parse(document.getElementById('_dash-config').textContent);", "oap_config;")  # in dev
+            txt_body = txt_body.replace("JSON.parse(document.getElementById(\"_dash-config\").textContent);", "oap_config;")  # in live
             txt_body = txt_body.replace('react-entry-point', _report_content_entry_id_)
         elif file_name == 'main.wrapper.js':
             static_media_path = f'{self.config.requests_pathname_prefix.lstrip("/")}wrapper-static/media/'
             txt_body = txt_body.replace('static/media/', static_media_path)
-            txt_body = txt_body.replace('getElementById("root")', f'getElementById("{_report_sidebar_entry_id_}")')
+            if os.getenv('ON_PROXY') == 'true':
+                txt_body = txt_body.replace('http://13.57.187.238:8001', 'https://localhost')
 
         return txt_body + "\n"
 
